@@ -10,7 +10,7 @@
 #
 #
 "K1p" <-
-function(S=35,T=25,P=0,pHscale="T",kSWS2scale=0){
+function(S=35,T=25,P=0,pHscale="T",kSWS2scale=0,warn="y"){
 
     nK <- max(length(S), length(T), length(P), length(pHscale), length(kSWS2scale))
 
@@ -62,7 +62,7 @@ function(S=35,T=25,P=0,pHscale="T",kSWS2scale=0){
     # ----------------- If needed, Pressure Correction ------------------
             
     if (any (P != 0)) 
-        K1P <- Pcorrect(Kvalue=K1P, Ktype="K1p", T=T, S=S, P=P, pHscale="SWS", 1., 1.)
+        K1P <- Pcorrect(Kvalue=K1P, Ktype="K1p", T=T, S=S, P=P, pHscale="SWS", 1., 1., warn=warn)
 
     ###----------------pH scale corrections
     
@@ -99,7 +99,9 @@ function(S=35,T=25,P=0,pHscale="T",kSWS2scale=0){
 
     ##------------Warnings
 
-    if (any (T>45 | S>45 | T<0) ) {warning("S and/or T is outside the range of validity of the formulation available for K1p in seacarb.")}
+    is_w <- warn == "y"
+
+    if (any (is_w & (T>45 | S>45 | T<0)) ) {warning("S and/or T is outside the range of validity of the formulation available for K1p in seacarb.")}
 
 
     attr(K1P,"unit")     = "mol/kg-soln"
